#set -x
check_CERT() {
  if [ -e /etc/hiveon-pub.pem ]; then
    openssl dgst -sha256 -verify /etc/hiveon-pub.pem -signature  cert.pem.sig  cert.pem >/dev/null  2>&1 
    res=$?
    if [ $res -ne 0 ]; then
      echo "RUNME: CANNOT VERIFY CERT !" >> /tmp/upgrade_result
      rm * -rf > /dev/null 2>&1
      exit 3
    fi
  fi
  if [ ! -f fw.tar.gz.sig ]; then
    echo "RUNME: CANNOT FIND FW SIGNATURE!" >> /tmp/upgrade_result
    rm * -rf > /dev/null 2>&1
    exit 4
  fi
  openssl dgst -sha256 -verify cert.pem -signature  fw.tar.gz.sig  fw.tar.gz >/dev/null  2>&1 
  res=$?
  if [ $res -ne 0 ]; then
    echo "RUNME: CANNOT VERIFY FW !" >> /tmp/upgrade_result
    rm * -rf > /dev/null 2>&1
    exit 5
  fi
}

check_SD() {
  if [ -e /dev/mmcblk0p1 ]; then
    SD="/dev/mmcblk0p1"
  elif [ -e /dev/mmcblk0 ]; then
    SD="/dev/mmcblk0"
  else
    echo "Error SD card!" >> /tmp/upgrade_result
  fi
}

check_MOUNT() {
  umount -f /dev/mmcblk* > /dev/null 2>&1 # for multiple mount
  mount | grep mmc > /dev/null;
  res_mount=$?
  if [ $res_mount -eq 0 ]; then
    echo "RUNME: CANNOT UNMOUNT SD, PLEASE REBOOT !" >> /tmp/upgrade_result
    exit 5
  fi

  while mount | grep volatile &>/dev/null; do # umount tmpfs on /tmp
    mount_tmpfs="$(mount | grep volatile | awk 'NR==1{print $3}')"
    umount -l "$mount_tmpfs" >/dev/null 2>&1
    sleep 1
  done
}

check_MEM() {
  sync; echo 1 > /proc/sys/vm/drop_caches >/dev/null 2>&1
  if [ "$(grep MemFree /proc/meminfo | awk '{print $2}')" -lt 60000 ]; then
    sh /www/pages/cgi-bin/stop_miner.cgi >/dev/null 2>&1
    sleep 15
  fi

  if [ "$(grep MemFree /proc/meminfo | awk '{print $2}')" -lt 60000 ]; then
    echo "RUNME: LOW MEMORY, PLEASE REBOOT !" >> /tmp/upgrade_result
    exit 5
  fi
}

start_MOUNT() {
  [ ! -d "/tmp/mnt" ] && mkdir -p /tmp/mnt
  mount -t vfat "$SD" /tmp/mnt
}

start_RUNME() {
  [ -d "/tmp/mnt/fw" ] && rm -rf /tmp/mnt/fw
  mkdir -p /tmp/mnt/fw
  tar zxvf fw.tar.gz -C /tmp/mnt/fw > /dev/null 2>&1
  rm fw.tar.gz
  cd /tmp/mnt/fw
  sh runme.sh
  sync >/dev/null 2>&1
  rm -f /config/norespawn >/dev/null 2>&1
  umount "$SD"
}

check_CERT
check_SD
check_MOUNT
check_MEM
start_MOUNT
start_RUNME

#end